﻿using IRaCIS.Core.Domain.Share;
using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.Filters;
using Microsoft.Extensions.Options;
using Newtonsoft.Json;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace IRaCIS.Core.Application.BusinessFilter
{
    public class EncreptApiResultFilter : IAsyncResultFilter
    {

        private readonly IOptionsMonitor<EncreptResponseOption> _encreptResponseMonitor;

        public EncreptApiResultFilter(IOptionsMonitor<EncreptResponseOption> encreptResponseMonitor)
        {
            _encreptResponseMonitor = encreptResponseMonitor;
        }

        public async Task OnResultExecutionAsync(ResultExecutingContext context, ResultExecutionDelegate next)
        {

            if(_encreptResponseMonitor.CurrentValue.IsEnable)
            {

                if (context.Result is ObjectResult objectResult)
                {
                    var statusCode = objectResult.StatusCode ?? context.HttpContext.Response.StatusCode;

                    var objectValue = objectResult.Value;


                    if (objectValue is IResponseOutput)
                    {
                        var responseOutput = objectValue as IResponseOutput<object>;

                        var path = context.HttpContext?.Request.Path.Value?.ToLower();


                        if(!string.IsNullOrEmpty(path)  && path.Length>5 && _encreptResponseMonitor.CurrentValue.ApiPathList.Contains(path.ToLower()))
                        {

                            if(responseOutput.IsSuccess)
                            {
                                responseOutput.Code = ApiResponseCodeEnum.ResultEncrepted;
                                responseOutput.Data = JsonConvert.SerializeObject(Convert.ToBase64String(Encoding.UTF8.GetBytes(responseOutput.Data.ToString())));

                                objectResult.Value = responseOutput;
                            }

                        }

                    }



                }
            }


           

            await next.Invoke();

        }
    }
}
